<?php

/*
 * This file is part of the Force Login module for Magento2.
 *
 * (c) bitExpert AG
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace bitExpert\ForceCustomerLogin\Observer;

use \bitExpert\ForceCustomerLogin\Api\Controller\LoginCheckInterface;
use \bitExpert\ForceCustomerLogin\Api\Observer\LoginRequiredObserverInterface;
use \Magento\Framework\Event\Observer;

/**
 * Class LoginRequiredOnCustomerSessionInitObserver
 * @package bitExpert\ForceCustomerLogin\Observer
 */
class LoginRequiredOnCustomerSessionInitObserver implements LoginRequiredObserverInterface
{
    /**
     * @var LoginCheckInterface
     */
    protected $loginCheckController;

    protected $_session;
    
    /**
     * Creates a new {@link \bitExpert\ForceCustomerLogin\Observer\LoginRequiredOnCustomerSessionInitObserver}.
     *
     * @param LoginCheckInterface $loginCheckController
     */
    public function __construct(LoginCheckInterface $loginCheckController,\Magento\Customer\Model\Session $session)
    {
        $this->loginCheckController = $loginCheckController;
        $this->_session = $session;
    }

    /**
     * {@inheritDoc}
     */
    public function execute(Observer $observer)
    {
        if ($this->_session->isLoggedIn()) {
            // Customer is logged in 
            return;
        } 

        // check if a redirect is mandatory
        $this->loginCheckController->execute();
    }
}
